==> haskell-http-client-0.7.6-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client
version:              0.7.6
visibility:           public
id:                   http-client-0.7.6-BevQRQQqOax6my61Vm1ERT
key:                  http-client-0.7.6-BevQRQQqOax6my61Vm1ERT
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  3028d9e945e7a8afa190a2b368062153
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-8.10.4/site-local/http-client-0.7.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/http-client-0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/http-client-0.7.6
hs-libraries:         HShttp-client-0.7.6-BevQRQQqOax6my61Vm1ERT
depends:
    array-0.5.4.0 base-4.14.1.0
    base64-bytestring-1.2.0.1-6uxiU3X5Npw7GePl6D3qX1
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L4eezPrloIkFfLdkfuDqXK containers-0.6.2.1
    cookie-0.4.5-Cr058gEywdbK8YE1EhasZd deepseq-1.4.4.0
    exceptions-0.10.4 filepath-1.4.2.1 ghc-prim-0.6.1
    http-types-0.12.3-DT6Dzx7GqMR7VNFOQ93DFz
    mime-types-0.1.0.9-K6bQZUQKIEd9EmFkYNVLGe
    network-3.1.2.1-3xGs6xqleCt2AU2p1KJfHx
    network-uri-2.6.4.1-6gXCpHwSW0e5lbvLi5Ccp1
    random-1.2.0-2visSit9X2t61PgLh8ZrY0 stm-2.5.0.0
    streaming-commons-0.2.2.1-Jk32og1deSt9ZGG90A9MhH text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.7.7-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client
version:              0.7.7
visibility:           public
id:                   http-client-0.7.7-D7vjrYvVLS6Lk8S0qvDw7B
key:                  http-client-0.7.7-D7vjrYvVLS6Lk8S0qvDw7B
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  b48e66265be32c1911064548bfdec058
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-8.10.4/site-local/http-client-0.7.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/http-client-0.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/http-client-0.7.7
hs-libraries:         HShttp-client-0.7.7-D7vjrYvVLS6Lk8S0qvDw7B
depends:
    array-0.5.4.0 base-4.14.1.0
    base64-bytestring-1.2.0.1-F61lor3jzVZ3hOhxyuaaSX
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ bytestring-0.10.12.0
    case-insensitive-1.2.1.0-DbGxz2JWIHa9dKN5hzOmMa containers-0.6.2.1
    cookie-0.4.5-Cr058gEywdbK8YE1EhasZd deepseq-1.4.4.0
    exceptions-0.10.4 filepath-1.4.2.1 ghc-prim-0.6.1
    http-types-0.12.3-G9nn79Z4cq6DCL5K0PZajM
    iproute-1.7.11-5BT2gKFxZ2Z1L6OcPIn6FS
    mime-types-0.1.0.9-K6bQZUQKIEd9EmFkYNVLGe
    network-3.1.2.1-FhOaehNchti9X3Dj4Rfk7n
    network-uri-2.6.4.1-3mv7RWF0Ao3K2iKwg9OxVv
    random-1.2.0-DOZvHpUFoYu5TC9oavXEso stm-2.5.0.0
    streaming-commons-0.2.2.1-GAEQTf9HYszDVexETtJYr text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
